## START: Set by rpmautospec
## (rpmautospec version 0.3.5)
## RPMAUTOSPEC: autorelease, autochangelog
%define autorelease(e:s:pb:n) %{?-p:0.}%{lua:
    release_number = 2;
    base_release_number = tonumber(rpm.expand("%{?-b*}%{!?-b:1}"));
    print(release_number + base_release_number - 1);
}%{?-e:.%{-e*}}%{?-s:.%{-s*}}%{!?-n:%{?dist}}
## END: Set by rpmautospec

%bcond_without  tests

%global         srcname     google-cloud-automl
%global         reponame    google-cloud-python

Name:           python-%{srcname}
Version:        2.11.4
Release:        %autorelease
Summary:        Python Client for Google Cloud AutoML API

License:        Apache-2.0
URL:            https://github.com/googleapis/google-cloud-python
Source0:        %{url}/archive/refs/tags/%{srcname}-v%{version}.tar.gz

BuildArch:      noarch

BuildRequires:  python3-devel

%if %{with tests}
BuildRequires:  python3dist(google-cloud-storage)
BuildRequires:  python3dist(pandas)
BuildRequires:  python3dist(pytest)
BuildRequires:  python3dist(pytest-asyncio)
%endif

%global _description %{expand:
The Cloud AutoML API is a suite of machine learning products that enables
developers with limited machine learning expertise to train high-quality
models specific to their business needs, by leveraging Google’s
state-of-the-art transfer learning, and Neural Architecture Search technology.}

%description %{_description}


%package -n python3-%{srcname}
Summary:        %{summary}

%description -n python3-%{srcname} %{_description}


%prep
# Upstream buries the package into a subdirectory. 😭
%setup -c -T
tar xzf %{SOURCE0} --strip-components=3 \
    %{reponame}-%{srcname}-v%{version}/packages/%{srcname}

# Allow a slightly older protobuf.
sed -i 's/"protobuf.*",/"protobuf>=3.19.4",/' setup.py

# Replace mock imports with unittest.mock.
grep -rl "^[[:space:]]*import mock" tests | \
    xargs sed -i -E 's/^([[:space:]]*)import mock/\1from unittest import mock/'


%generate_buildrequires
%pyproject_buildrequires -r


%build
%pyproject_wheel


%install
%pyproject_install
%pyproject_save_files google

# Remove extra scripts.
rm -f %{buildroot}%{_bindir}/fixup_automl*.py


%check
%pyproject_check_import

%if %{with tests}
# NOTE(mhayden): Setting PYTHONUSERBASE as a hack for PEP 420 namespaces.
# Thanks to churchyard for the fix.
PYTHONUSERBASE=%{buildroot}%{_prefix} \
    %pytest tests/unit
%endif


%files -n python3-%{srcname} -f %{pyproject_files}
%license LICENSE
%doc README.rst CHANGELOG.md
%{python3_sitelib}/google_cloud_automl-%{version}-py%{python3_version}-nspkg.pth


%changelog
* Wed Dec 06 2023 Nikola Forró <nforro@redhat.com> - 2.11.4-2
- Do not sync release candidate versions

* Fri Nov 17 2023 Major Hayden <major@redhat.com> - 2.11.4-1
- Update to 2.11.4 rhbz#2249865

* Mon Oct 23 2023 Major Hayden <major@redhat.com> - 2.11.3-1
- Update to 2.11.3 rhbz#2244506

* Mon Oct 23 2023 Major Hayden <major@redhat.com> - 2.11.2-3
- Add packit config

* Fri Jul 21 2023 Fedora Release Engineering <releng@fedoraproject.org> - 2.11.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_39_Mass_Rebuild

* Thu Jul 06 2023 Major Hayden <major@redhat.com> - 2.11.2-1
- Update to 2.11.2 rhbz#2219851

* Mon Mar 27 2023 Major Hayden <major@redhat.com> - 2.11.1-1
- Update to 2.11.1 rhbz#2182107

* Wed Mar 01 2023 Major Hayden <major@redhat.com> - 2.11.0-1
- Update to 2.11.0 rhbz#2174252

* Tue Feb 21 2023 Major Hayden <major@redhat.com> - 2.10.1-1
- Update to 2.10.1

* Fri Feb 10 2023 Major Hayden <major@redhat.com> - 2.8.3-3
- Disable tests temporarily due to broken imports

* Fri Jan 20 2023 Fedora Release Engineering <releng@fedoraproject.org> - 2.8.3-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_38_Mass_Rebuild

* Wed Oct 19 2022 Major Hayden <major@redhat.com> - 2.8.3-1
- Update to 2.8.3 rhbz#2131857

* Mon Aug 15 2022 Major Hayden <major@redhat.com> - 2.8.1-1
- Update to 2.8.1 rhbz#2118351

* Wed Jul 27 2022 Major Hayden <major@redhat.com> - 2.8.0-1
- Update to 2.8.0 rhbz#2108613

* Fri Jul 22 2022 Fedora Release Engineering <releng@fedoraproject.org> - 2.7.3-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_37_Mass_Rebuild

* Tue Jun 28 2022 Python Maint <python-maint@redhat.com> - 2.7.3-2
- Rebuilt for Python 3.11

* Mon Jun 13 2022 Major Hayden <major@redhat.com> - 2.7.3-1
- Update to 2.7.3

* Tue Mar 08 2022 Major Hayden <major@mhtx.net> - 2.7.2-1
- Update to 2.7.2

* Tue Mar 01 2022 Major Hayden <major@mhtx.net> - 2.7.1-1
- Update to 2.7.1

* Wed Feb 23 2022 Major Hayden <major@mhtx.net> - 2.7.0-1
- Update to 2.7.0

* Fri Jan 21 2022 Fedora Release Engineering <releng@fedoraproject.org> - 2.6.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_36_Mass_Rebuild

* Tue Jan 18 2022 Major Hayden <major@mhtx.net> - 2.6.0-1
- Update to 2.6.0

* Thu Nov 04 2021 Major Hayden <major@mhtx.net> - 2.5.2-1
- Update to 2.5.2

* Thu Oct 21 2021 Major Hayden <major@mhtx.net> - 2.5.1-1
- Update to 2.5.1

* Mon Oct 11 2021 Major Hayden <major@mhtx.net> - 2.5.0-1
- Update to 2.5.0

* Tue Oct 05 2021 Major Hayden <major@mhtx.net> - 2.4.2-1
- Initial import (#1998346)
